@@ -16,8 +16,8 @@ sph2car = function(x) {
 
   if (length(unlist(x,use.names = FALSE))==3) x = matrix(x,1,3)
 
-  return(data.frame(x=x[,1]*sin(x[,2])*cos(x[,3]),
-                    y=x[,1]*sin(x[,2])*sin(x[,3]),
-                    z=x[,1]*cos(x[,2])))
+  return(cbind(x=x[,1]*sin(x[,2])*cos(x[,3]),
+               y=x[,1]*sin(x[,2])*sin(x[,3]),
+               z=x[,1]*cos(x[,2])))
 
 }
